CREATE SCHEMA Entwurf

-- Historie:
--
-- 12.09.2001 - 1.003 (1.004)
-- berarbeitung in Folge des nderungsantrags A0006
--
-- 17.12.2000 - 1.002 (1.002)
-- Integration symbolischer Verweise fr Netzknoten
--
-- 29.10.2000 - 1.001 (1.001)
-- passive Versionierung durch Integration der
-- Schemata allgemeine Geometrieobjekte und Grunderwerb
--
-- 15.10.1999 - 1.000 (1.000)
-- Erste Version des OKSTRA verabschiedet

CREATE TABLE Trasse (
   Trasse_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Trasse_ID) REFERENCES allgemeine_Eigenschaften,
   hat_Netzknoten
      INTEGER REFERENCES Strassennetz.Netzknoten_abstrakt
)

CREATE TABLE Trasse__hat_Achse (
   Trasse
      INTEGER NOT NULL REFERENCES Trasse,
   Achse
      INTEGER NOT NULL REFERENCES Achse
)

CREATE TABLE Trasse__hat_Entwurfsparameter (
   Trasse
      INTEGER NOT NULL REFERENCES Trasse,
   Entwurfsparameter
      INTEGER NOT NULL REFERENCES Entwurfsparameter
)

CREATE TABLE Trasse__hat_Laengsschnitt (
   Trasse
      INTEGER NOT NULL REFERENCES Trasse,
   Laengsschnitt
      INTEGER NOT NULL REFERENCES Laengsschnitt
)

CREATE TABLE Trasse__hat_Trassenkoerper (
   Trasse
      INTEGER NOT NULL REFERENCES Trasse,
   Trassenkoerper
      INTEGER NOT NULL REFERENCES Trassenkoerper
)

CREATE TABLE Trasse__hat_Sichtweiten (
   Trasse
      INTEGER NOT NULL REFERENCES Trasse,
   Sichtweiten
      INTEGER NOT NULL REFERENCES Sichtweiten
)

CREATE TABLE Achse (
   Achse_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Achse_ID) REFERENCES allgemeine_Eigenschaften
)

CREATE TABLE Achselement (
   Achselement_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Achselement_ID) REFERENCES allgemeine_Eigenschaften,
   folgt_auf_Achselement
      INTEGER REFERENCES Achselement,
   Elementtyp
      INTEGER NOT NULL REFERENCES Achselementtyp,
   Anfangsstation_rechnerisch
      REAL NOT NULL, -- Meter
   CHECK ( Anfangsstation_rechnerisch>=0 ),
   Verwaltungsstation_Betriebskm
      REAL NOT NULL, -- Groesse
   CHECK ( Verwaltungsstation_Betriebskm>=0 ),
   Laenge
      REAL NOT NULL, -- Meter
   CHECK ( Laenge>=0 ),
   Richtung
      REAL NOT NULL, -- Winkel
   Parameter
      FLOAT (16) NOT NULL,
   Radius_zu_Beginn
      REAL NOT NULL, -- Meter
   CHECK ( Radius_zu_Beginn>=0 ),
   Radius_am_Ende
      REAL NOT NULL, -- Meter
   CHECK ( Radius_am_Ende>=0 ),
   beginnt_bei_Achshauptpunkt
      INTEGER NOT NULL REFERENCES Achshauptpunkt,
   endet_bei_Achshauptpunkt
      INTEGER NOT NULL REFERENCES Achshauptpunkt,
   gehoert_zu_Achse
      INTEGER REFERENCES Achse
)

CREATE TABLE Linienelementtyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Linienelementtyp VALUES (0,'reserviert')
INSERT INTO Linienelementtyp VALUES (1,'Gerade')
INSERT INTO Linienelementtyp VALUES (2,'Kreisbogen, tangentialer Abschlu')
INSERT INTO Linienelementtyp VALUES (3,'Kreisbogen, 3 Punkte')
INSERT INTO Linienelementtyp VALUES (4,'Kreisbogen aus Mittelpunkt und Radius')
INSERT INTO Linienelementtyp VALUES (5,'Spline, tangentialer Abschlu')
INSERT INTO Linienelementtyp VALUES (6,'Spline')
INSERT INTO Linienelementtyp VALUES (7,'Spline-Ende, tangentialer Abschlu')
INSERT INTO Linienelementtyp VALUES (8,'Spline-Ende')
INSERT INTO Linienelementtyp VALUES (9,'Spline-Ende und -Anfang mit '+
 'Knickpunkt Spline')
INSERT INTO Linienelementtyp VALUES (10,'reserviert')
INSERT INTO Linienelementtyp VALUES (11,'reserviert')
INSERT INTO Linienelementtyp VALUES (12,'Klothoide')
INSERT INTO Linienelementtyp VALUES (13,'quadratische Parabel')
INSERT INTO Linienelementtyp VALUES (14,'kubische Parabel, langer Ast links')
INSERT INTO Linienelementtyp VALUES (15,'kubische Parabel, langer Ast rechts')

CREATE TABLE Achselementtyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Achselementtyp VALUES (0,'reserviert')
INSERT INTO Achselementtyp VALUES (1,'Gerade')
INSERT INTO Achselementtyp VALUES (2,'Kreisbogen, tangential')
INSERT INTO Achselementtyp VALUES (11,'Klothoide')

CREATE TABLE Achshauptpunkt (
   Achshauptpunkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Achshauptpunkt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell
)

CREATE TABLE Kreuzungs_o_Einmuendungsplang (
   Kreuzungs_o_Einmuendungsplang_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Kreuzungs_o_Einmuendungsplang_ID) REFERENCES allgemeine_Eigenschaften,
   Netzknotennummer
      VARCHAR(7) NOT NULL,
   Knotenpunktsform
      INTEGER NOT NULL REFERENCES Strassennetz.Knotenpunktsform,
   hat_DGM
      INTEGER REFERENCES DGM,
   hat_Achshauptpunkt
      INTEGER NOT NULL REFERENCES Achshauptpunkt
)

CREATE TABLE Kreuz_o_Einmplang__hat_Achse (
   Kreuzungs_o_Einmuendungsplang
      INTEGER NOT NULL REFERENCES Kreuzungs_o_Einmuendungsplang,
   Achse
      INTEGER NOT NULL REFERENCES Achse
)

CREATE TABLE DGM (
   DGM_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (DGM_ID) REFERENCES allgemeine_Eigenschaften
)

CREATE TABLE Laengsschnitt (
   Laengsschnitt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Laengsschnitt_ID) REFERENCES allgemeine_Eigenschaften,
   abs_Abstand
      FLOAT (16),
   gehoert_zu_Achse
      INTEGER NOT NULL REFERENCES Achse
)

CREATE TABLE Laengsschnitt__hat_Breite (
   Laengsschnitt
      INTEGER NOT NULL REFERENCES Laengsschnitt,
   Breite
      INTEGER NOT NULL REFERENCES Breite
)

CREATE TABLE Laengsschn__hat_kreuz_Bauwerke (
   Laengsschnitt
      INTEGER NOT NULL REFERENCES Laengsschnitt,
   kreuzende_Bauwerke_o_baul_Anl
      INTEGER NOT NULL REFERENCES kreuzende_Bauwerke_o_baul_Anl
)

CREATE TABLE Laengsschn__hat_Gelaendehoriz (
   Laengsschnitt
      INTEGER NOT NULL REFERENCES Laengsschnitt,
   Gelaendehorizonte
      INTEGER NOT NULL REFERENCES Gelaendehorizonte
)

CREATE TABLE Laengsschnitt__hat_Gradiente (
   Laengsschnitt
      INTEGER NOT NULL REFERENCES Laengsschnitt,
   Gradiente
      INTEGER NOT NULL REFERENCES Gradiente
)

CREATE TABLE Gelaendehorizonte (
   Gelaendehorizonte_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Gelaendehorizonte_ID) REFERENCES Laengsschnittlinie
)

CREATE TABLE Gradiente (
   Gradiente_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Gradiente_ID) REFERENCES Laengsschnittlinie
)

CREATE TABLE kreuzende_Bauwerke_o_baul_Anl (
   kreuzende_Bauwerke_o_baul_Anl_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (kreuzende_Bauwerke_o_baul_Anl_ID) REFERENCES allgemeine_Eigenschaften,
   hat_Tunnel_Kanal_Strasse_etc
      INTEGER REFERENCES Tunnel_Kanal_Strasse_Durchlass
)

CREATE TABLE kreuz_Bauwerk__hat_Schnittgeom (
   kreuzende_Bauwerke_o_baul_Anl
      INTEGER NOT NULL REFERENCES kreuzende_Bauwerke_o_baul_Anl,
   Schnittgeometrie
      INTEGER NOT NULL REFERENCES Schnittgeometrie
)

CREATE TABLE Tunnel_Kanal_Strasse_Durchlass (
   Tunnel_Kanal_Strasse_Durchlass_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Schnittgeometrie (
   Schnittgeometrie_ID
      INTEGER NOT NULL PRIMARY KEY,
   Schnittstation
      REAL NOT NULL, -- Meter
   CHECK ( Schnittstation>=0 ),
   Schnitthoehe
      REAL NOT NULL, -- Meter
   CHECK ( Schnitthoehe>=0 ),
   Schnittwinkel_horizontal
      REAL NOT NULL, -- Winkel
   Laengsneigung_kreuzend_Bauwerk
      REAL NOT NULL, -- Winkel
   abgel_von_Tunnel_Kanal_Str_etc
      INTEGER NOT NULL REFERENCES Tunnel_Kanal_Strasse_Durchlass
)

CREATE TABLE Schnittgeom__hat_Schnpolygone (
   Schnittgeometrie
      INTEGER NOT NULL REFERENCES Schnittgeometrie,
   Schnittpolygone
      INTEGER NOT NULL REFERENCES Schnittpolygone
)

CREATE TABLE Schnittgeom__hat_Mindabstpolyg (
   Schnittgeometrie
      INTEGER NOT NULL REFERENCES Schnittgeometrie,
   Mindestabstandspolygon
      INTEGER NOT NULL REFERENCES Mindestabstandspolygon
)

CREATE TABLE Schnittgeom__hat_Maxabstpolyg (
   Schnittgeometrie
      INTEGER NOT NULL REFERENCES Schnittgeometrie,
   Maximalabstandspolygon
      INTEGER NOT NULL REFERENCES Maximalabstandspolygon
)

CREATE TABLE Schnittpolygone (
   Schnittpolygone_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Schnittpolygone_ID) REFERENCES Polygon
)

CREATE TABLE Mindestabstandspolygon (
   Mindestabstandspolygon_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Mindestabstandspolygon_ID) REFERENCES Polygon
)

CREATE TABLE Maximalabstandspolygon (
   Maximalabstandspolygon_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Maximalabstandspolygon_ID) REFERENCES Polygon
)

CREATE TABLE Polygon (
   Polygon_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Polygon__hat_QP_Punkte (
   Polygon
      INTEGER NOT NULL REFERENCES Polygon,
   QP_Punkte
      INTEGER NOT NULL REFERENCES QP_Punkte,
   folgt_auf_QP_Punkte
      INTEGER REFERENCES QP_Punkte
)

CREATE TABLE Laengsschnittlinie (
   Laengsschnittlinie_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Laengsschnittlinie_ID) REFERENCES allgemeine_Eigenschaften,
   hat_Spurbezeichnung
      INTEGER REFERENCES Spurbezeichnung,
   hat_DGM
      INTEGER REFERENCES DGM
)

CREATE TABLE Laengsschnittl__hat_LS_Koor (
   Laengsschnittlinie
      INTEGER NOT NULL REFERENCES Laengsschnittlinie,
   LS_Koor
      INTEGER NOT NULL REFERENCES LS_Koor,
   folgt_auf_LS_Koor
      INTEGER REFERENCES LS_Koor
)

CREATE TABLE LS_Koor (
   LS_Koor_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (LS_Koor_ID) REFERENCES allgemeine_Eigenschaften,
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 ),
   Hoehe
      REAL NOT NULL, -- Meter
   CHECK ( Hoehe>=0 ),
   folgt_auf_LS_Koor
      INTEGER REFERENCES Punktfolge
)

CREATE TABLE Punktfolge (
   Punktfolge_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Tangente_Gerade
      INTEGER NOT NULL REFERENCES Tangente_Gerade
)

CREATE TABLE Tangentenfolge (
   Tangentenfolge_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Ausrundung
      INTEGER REFERENCES Ausrundung
)

CREATE TABLE Ausrundung (
   Ausrundung_ID
      INTEGER NOT NULL PRIMARY KEY,
   Ausrundungstyp
      INTEGER REFERENCES Ausrundungstyp,
   Ausrundungsparameter
      FLOAT (16)
)

CREATE TABLE Ausrundungstyp (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Ausrundungstyp VALUES (12,'Parabel 2. Grades')
INSERT INTO Ausrundungstyp VALUES (13,'Parabel 3. Grades mit langem Teil '+
 'vor TS')
INSERT INTO Ausrundungstyp VALUES (14,'Parabel 3. Grades mit langem Teil '+
 'hinter TS')

CREATE TABLE Tangente_Gerade (
   Tangente_Gerade_ID
      INTEGER NOT NULL PRIMARY KEY,
   folgt_auf_Tangente_Gerade
      INTEGER REFERENCES Tangentenfolge
)

CREATE TABLE Volumen_aus_QP (
   Volumen_aus_QP_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Volumen_aus_QP_ID) REFERENCES allgemeine_Eigenschaften,
   Station_1
      REAL NOT NULL, -- Meter
   CHECK ( Station_1>=0 ),
   Station_2
      REAL NOT NULL, -- Meter
   CHECK ( Station_2>=0 ),
   wird_begrenzt_von_Profillinie
      INTEGER NOT NULL REFERENCES Profillinien
)

CREATE TABLE Oberflaeche (
   Oberflaeche_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Oberflaeche_ID) REFERENCES allgemeine_Eigenschaften,
   Art_der_Oberflaeche
      INTEGER NOT NULL,
   Station_1
      REAL NOT NULL, -- Meter
   CHECK ( Station_1>=0 ),
   Station_2
      REAL NOT NULL, -- Meter
   CHECK ( Station_2>=0 ),
   liegt_auf_Profillinie
      INTEGER NOT NULL REFERENCES Profillinien,
   beginnt_bei_QP_Punkt
      INTEGER NOT NULL REFERENCES QP_Punkte,
   endet_bei_QP_Punkt
      INTEGER NOT NULL REFERENCES QP_Punkte
)

CREATE TABLE Trassenkoerper (
   Trassenkoerper_ID
      INTEGER NOT NULL PRIMARY KEY,
   gehoert_zu_Achse
      INTEGER NOT NULL REFERENCES Achse
)

CREATE TABLE Trassenkoerper__hat_Volumen (
   Trassenkoerper
      INTEGER NOT NULL REFERENCES Trassenkoerper,
   Volumen_aus_QP
      INTEGER NOT NULL REFERENCES Volumen_aus_QP
)

CREATE TABLE Trassenkoerper__hat_Oberfl (
   Trassenkoerper
      INTEGER NOT NULL REFERENCES Trassenkoerper,
   Oberflaeche
      INTEGER NOT NULL REFERENCES Oberflaeche
)

CREATE TABLE Trassenkoerper__hat_Deckenbuch (
   Trassenkoerper
      INTEGER NOT NULL REFERENCES Trassenkoerper,
   Deckenbuch
      INTEGER NOT NULL REFERENCES Deckenbuch
)

CREATE TABLE Trassenkoerper__hat_Querprofil (
   Trassenkoerper
      INTEGER NOT NULL REFERENCES Trassenkoerper,
   Querprofil
      INTEGER NOT NULL REFERENCES Querprofil
)

CREATE TABLE Trassenkoerper__hat_Ausgdaten (
   Trassenkoerper
      INTEGER NOT NULL REFERENCES Trassenkoerper,
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten
)

CREATE TABLE Trassenkoerper__hat_Bildgsges (
   Trassenkoerper
      INTEGER NOT NULL REFERENCES Trassenkoerper,
   Bildungsgesetze
      INTEGER NOT NULL REFERENCES Bildungsgesetze
)

CREATE TABLE Querprofil (
   Querprofil_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 ),
   hat_Schnittebene
      INTEGER REFERENCES Schnittebene,
   folgt_auf_Querprofil
      INTEGER REFERENCES Querprofil
)

CREATE TABLE Querpr__von_Ausgdaten_Bildges (
   Querprofil
      INTEGER NOT NULL REFERENCES Querprofil,
   Ausgangsdaten_Bildungsgesetze
      INTEGER NOT NULL REFERENCES Ausgangsdaten_Bildungsgesetze
)

CREATE TABLE Querprofil__hat_Profillinien (
   Querprofil
      INTEGER NOT NULL REFERENCES Querprofil,
   Profillinien
      INTEGER NOT NULL REFERENCES Profillinien
)

CREATE TABLE Querprofil__hat_QP_Punkte (
   Querprofil
      INTEGER NOT NULL REFERENCES Querprofil,
   QP_Punkte
      INTEGER NOT NULL REFERENCES QP_Punkte
)

CREATE TABLE Bildungsgesetze (
   Bildungsgesetze_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Ausgangsdaten_Bildungsgesetze (
   Ausgangsdaten_Bildungsgesetze_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bildungsgesetze
      INTEGER NOT NULL REFERENCES Bildungsgesetze,
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten
)

CREATE TABLE Ausgangsdaten (
   Ausgangsdaten_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Ausgangsdaten__hat_Querprofil (
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten,
   Querprofil
      INTEGER NOT NULL REFERENCES Querprofil
)

CREATE TABLE Ausgangsdaten__hat_Breite (
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten,
   Breite
      INTEGER NOT NULL REFERENCES Breite
)

CREATE TABLE Ausgangsdaten__hat_Querneigung (
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten,
   Querneigung
      INTEGER NOT NULL REFERENCES Querneigung
)

CREATE TABLE Ausgangsdaten__hat_Hoehendifferenz (
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten,
   Hoehendifferenz
      INTEGER NOT NULL REFERENCES Hoehendifferenz
)

CREATE TABLE Ausgangsdaten__hat_Hoehenzuege (
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten,
   Hoehenzuege
      INTEGER NOT NULL REFERENCES Hoehenzuege
)

CREATE TABLE Ausgangsd__hat_Achsstationsw (
   Ausgangsdaten
      INTEGER NOT NULL REFERENCES Ausgangsdaten,
   Achsstationswerte
      INTEGER NOT NULL REFERENCES Achsstationswerte
)

CREATE TABLE Hoehenzuege (
   Hoehenzuege_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE QP_Punkte (
   QP_Punkte_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (QP_Punkte_ID) REFERENCES allgemeine_Eigenschaften,
   Abstand_zur_Achse
      FLOAT (16) NOT NULL,
   Hoehe_NN
      FLOAT (16) NOT NULL,
   hat_Querprofilpunkt
      INTEGER REFERENCES Querprofilpunkt
)

CREATE TABLE Querprofilpunkt (
   Querprofilpunkt_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Profillinien (
   Profillinien_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Profillinien_ID) REFERENCES allgemeine_Eigenschaften
)

CREATE TABLE Profillinien__hat_QP_Punkte (
   Profillinien
      INTEGER NOT NULL REFERENCES Profillinien,
   QP_Punkte
      INTEGER NOT NULL REFERENCES QP_Punkte,
   folgt_auf_QP_Punkte
      INTEGER REFERENCES QP_Punkte
)

CREATE TABLE Schnittebene (
   Schnittebene_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Schnittebene__hat_SNT_Punkte (
   Schnittebene
      INTEGER NOT NULL REFERENCES Schnittebene,
   SNT_Punkt
      INTEGER NOT NULL REFERENCES SNT_Punkt,
   folgt_auf_SNT_Punkt
      INTEGER REFERENCES SNT_Punkt
)

CREATE TABLE SNT_Punkt (
   SNT_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Abstand
      REAL NOT NULL, -- Meter
   CHECK ( Abstand>=0 ),
   Richtungsaenderung
      FLOAT (16) NOT NULL,
   korrespondierende_Achse
      VARCHAR(255),
   Naeherungsstation
      REAL, -- Meter
   CHECK ( Naeherungsstation>=0 )
)

CREATE TABLE Deckenbuch (
   Deckenbuch_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Deckenbuch_ID) REFERENCES allgemeine_Eigenschaften,
   Station_1
      REAL NOT NULL, -- Meter
   CHECK ( Station_1>=0 ),
   Station_2
      REAL NOT NULL, -- Meter
   CHECK ( Station_2>=0 )
)

CREATE TABLE Deckenb__hat_Spur_a_Ausgangsd (
   Deckenbuch
      INTEGER NOT NULL REFERENCES Deckenbuch,
   Spur_aus_Ausgangsdaten
      INTEGER NOT NULL REFERENCES Spur_aus_Ausgangsdaten,
   folgt_auf_Spur_aus_Ausgdaten
      INTEGER REFERENCES Spur_aus_Ausgangsdaten
)

CREATE TABLE Deckenb__hat_Spur_aus_Querprof (
   Deckenbuch
      INTEGER NOT NULL REFERENCES Deckenbuch,
   Spur_aus_Querprofilen
      INTEGER NOT NULL REFERENCES Spur_aus_Querprofilen,
   folgt_auf_Spur_aus_Querprof
      INTEGER REFERENCES Spur_aus_Querprofilen
)

CREATE TABLE Spurfolge_Ausgangsdaten (
   Spurfolge_Ausgangsdaten_ID
      INTEGER NOT NULL PRIMARY KEY,
   Hoehendifferenz
      REAL NOT NULL, -- Meter
   CHECK ( Hoehendifferenz>=0 )
)

CREATE TABLE Spur_aus_Ausgangsdaten (
   Spur_aus_Ausgangsdaten_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Spur_aus_Ausgangsdaten_ID) REFERENCES allgemeine_Eigenschaften,
   folgt_auf_Spur_aus_Ausgangsdat
      INTEGER REFERENCES Spurfolge_Ausgangsdaten,
   hat_Querneigung
      INTEGER REFERENCES Querneigung,
   hat_Hoehendifferenz
      INTEGER REFERENCES Hoehendifferenz,
   hat_Breite
      INTEGER NOT NULL REFERENCES Breite
)

CREATE TABLE Spur_a_Ausgdaten__hat_Hoehenz (
   Spur_aus_Ausgangsdaten
      INTEGER NOT NULL REFERENCES Spur_aus_Ausgangsdaten,
   Hoehenzuege
      INTEGER NOT NULL REFERENCES Hoehenzuege
)

CREATE TABLE Spur_aus_Querprofilen (
   Spur_aus_Querprofilen_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Spur_aus_Querprofilen_ID) REFERENCES allgemeine_Eigenschaften,
   liegt_auf_Profillinie
      INTEGER NOT NULL REFERENCES Profillinien,
   beginnt_bei_QP_Punkt
      INTEGER NOT NULL REFERENCES QP_Punkte,
   endet_bei_QP_Punkt
      INTEGER NOT NULL REFERENCES QP_Punkte
)

CREATE TABLE Breite (
   Breite_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Breite_ID) REFERENCES allgemeine_Eigenschaften,
   hat_Spurbezeichnung
      INTEGER REFERENCES Spurbezeichnung
)

CREATE TABLE Breite__hat_BR_Punkt (
   Breite
      INTEGER NOT NULL REFERENCES Breite,
   BR_Punkt
      INTEGER NOT NULL REFERENCES BR_Punkt,
   folgt_auf_BR_Punkt
      INTEGER REFERENCES BR_Punkt
)

CREATE TABLE BR_Punktfolge (
   BR_Punktfolge_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE BR_Punktf__hat_Aufw_Verbr_Verb (
   BR_Punktfolge
      INTEGER NOT NULL REFERENCES BR_Punktfolge,
   Aufweitung_Verbreit_Verbind
      INTEGER NOT NULL REFERENCES Aufweitung_Verbreit_Verbind
)

CREATE TABLE BR_Punkt (
   BR_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   Breite
      REAL, -- Meter
   CHECK ( Breite>=0 ),
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 ),
   hat_Abstand_Achse_Achse
      INTEGER REFERENCES Abstand_Achse_Achse,
   hat_Abstand_Achse_Linie
      INTEGER REFERENCES Abstand_Achse_Linie,
   folgt_auf_BR_Punkt
      INTEGER REFERENCES BR_Punktfolge
)

CREATE TABLE Aufweitung_Verbreit_Verbind (
   Aufweitung_Verbreit_Verbind_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Parabelfolge_zweit_Grades
      INTEGER REFERENCES Parabelfolge_zweiten_Grades,
   hat_Bogenfolge
      INTEGER REFERENCES Bogenfolge,
   hat_Parabelf_zw_Grad_zw_Gerade
      INTEGER REFERENCES Parabelf_zw_Grades_zw_Gerade,
   hat_Gerade
      INTEGER REFERENCES Gerade
)

CREATE TABLE Parabelfolge_zweiten_Grades (
   Parabelfolge_zweiten_Grades_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Bogenfolge (
   Bogenfolge_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Parabelf_zw_Grades_zw_Gerade (
   Parabelf_zw_Grades_zw_Gerade_ID
      INTEGER NOT NULL PRIMARY KEY,
   Tangentenlaenge
      REAL NOT NULL, -- Meter
   CHECK ( Tangentenlaenge>=0 )
)

CREATE TABLE Gerade (
   Gerade_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Abstand_Achse_Achse (
   Abstand_Achse_Achse_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Lage_der_Knicklinie
      INTEGER NOT NULL REFERENCES Lage_der_Knicklinie,
   hat_zweite_Achse
      INTEGER NOT NULL REFERENCES zweite_Achse,
   hat_Naehergsstat_auf_zw_Achse
      INTEGER NOT NULL REFERENCES Naeherungsstation_auf_zw_Achse
)

CREATE TABLE Abstand_Achse_Linie (
   Abstand_Achse_Linie_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Abstand_Achse_Linie_ID) REFERENCES Geometrieschema.Linienobjekt_Modell
)

CREATE TABLE Lage_der_Knicklinie (
   Lage_der_Knicklinie_ID
      INTEGER NOT NULL PRIMARY KEY,
   hat_Parall_Breite_z_Achse_zwei
      INTEGER REFERENCES Parallele_Breite_z_Achse_zwei,
   hat_Parall_Breite_z_Achse_eins
      INTEGER REFERENCES Parallele_Breite_z_Achse_eins,
   ist_mittig_m_Abst_z_Knicklinie
      INTEGER REFERENCES mittig_m_Abstand_z_Knicklinie
)

CREATE TABLE zweite_Achse (
   zweite_Achse_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Naeherungsstation_auf_zw_Achse (
   Naeherungsstation_auf_zw_Achse_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Parallele_Breite_z_Achse_zwei (
   Parallele_Breite_z_Achse_zwei_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Parallele_Breite_z_Achse_zwei_ID) REFERENCES Breite
)

CREATE TABLE Parallele_Breite_z_Achse_eins (
   Parallele_Breite_z_Achse_eins_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Parallele_Breite_z_Achse_eins_ID) REFERENCES Breite
)

CREATE TABLE mittig_m_Abstand_z_Knicklinie (
   mittig_m_Abstand_z_Knicklinie_ID
      INTEGER NOT NULL PRIMARY KEY
)

CREATE TABLE Querneigung (
   Querneigung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Querneigung_ID) REFERENCES allgemeine_Eigenschaften,
   hat_Spurbezeichnung
      INTEGER REFERENCES Spurbezeichnung
)

CREATE TABLE Querneigung__hat_QN_Punkte (
   Querneigung
      INTEGER NOT NULL REFERENCES Querneigung,
   QN_Punkt
      INTEGER NOT NULL REFERENCES QN_Punkt,
   folgt_auf_QN_Punkt
      INTEGER REFERENCES QN_Punkt
)

CREATE TABLE Querneigungswechsel (
   Querneigungswechsel_ID
      INTEGER NOT NULL PRIMARY KEY,
   Verziehungsform
      INTEGER NOT NULL REFERENCES Verziehungsform
)

CREATE TABLE Verziehungsform (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Langtext
      VARCHAR(255) NOT NULL
)

INSERT INTO Verziehungsform VALUES (0,'reserviert')
INSERT INTO Verziehungsform VALUES (1,'normale Verziehung')
INSERT INTO Verziehungsform VALUES (2,'Verziehung mit Gratlinie '+
 '(Schrgverwindung)')

CREATE TABLE QN_Punkt (
   QN_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (QN_Punkt_ID) REFERENCES allgemeine_Eigenschaften,
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 ),
   Querneigung
      REAL NOT NULL,
   folgt_auf_QN_Punkt
      INTEGER REFERENCES Querneigungswechsel,
   gehoert_zu_Querneigung
      INTEGER NOT NULL REFERENCES Querneigung
)

CREATE TABLE Spurbezeichnung (
   Spurbezeichnung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Spurbezeichnung_ID) REFERENCES allgemeine_Eigenschaften
)

CREATE TABLE Achsstationswerte (
   Achsstationswerte_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Achsstationswerte_ID) REFERENCES allgemeine_Eigenschaften
)

CREATE TABLE Achsstationswerte__hat_AW_Koor (
   Achsstationswerte
      INTEGER NOT NULL REFERENCES Achsstationswerte,
   AW_Koor
      INTEGER NOT NULL REFERENCES AW_Koor,
   folgt_auf_AW_Koor
      INTEGER REFERENCES AW_Koor
)

CREATE TABLE AW_Koor (
   AW_Koor_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 ),
   Character_Kennwert
      VARCHAR(255) NOT NULL,
   Integer_Kennwert
      INTEGER NOT NULL,
   Real_Kennwert
      REAL NOT NULL
)

CREATE TABLE Entwurfsparameter (
   Entwurfsparameter_ID
      INTEGER NOT NULL PRIMARY KEY,
   Strassenkategorie
      VARCHAR(255) NOT NULL,
   Verkehrsbelastung
      INTEGER NOT NULL,
   Dokumentenverweis
      VARCHAR(255) NOT NULL,
   Regelquerschnitt
      VARCHAR(255) NOT NULL
)

CREATE TABLE Entwurfsparam__hat_Geschwband (
   Entwurfsparameter
      INTEGER NOT NULL REFERENCES Entwurfsparameter,
   Geschwindigkeitsband
      INTEGER NOT NULL REFERENCES Geschwindigkeitsband
)

CREATE TABLE Geschwindigkeitsband (
   Geschwindigkeitsband_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Geschwindigkeitsband_ID) REFERENCES allgemeine_Eigenschaften
)

CREATE TABLE Geschwindigkeitsb__hat_V_Koor (
   Geschwindigkeitsband
      INTEGER NOT NULL REFERENCES Geschwindigkeitsband,
   V_Koor
      INTEGER NOT NULL REFERENCES V_Koor,
   folgt_auf_V_Koor
      INTEGER REFERENCES V_Koor
)

CREATE TABLE V_Koor (
   V_Koor_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 ),
   Geschwindigkeit
      INTEGER NOT NULL, -- Stundenkilometer
   CHECK ( Geschwindigkeit>=0 )
)

CREATE TABLE Sichtweiten (
   Sichtweiten_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Sichtweiten_ID) REFERENCES allgemeine_Eigenschaften,
   Sichtweite
      FLOAT (16) NOT NULL,
   gehoert_zu_Achse
      INTEGER NOT NULL REFERENCES Achse,
   hat_Spurbezeichnung
      INTEGER REFERENCES Spurbezeichnung
)

CREATE TABLE Sichtweiten__hat_SW_Koor (
   Sichtweiten
      INTEGER NOT NULL REFERENCES Sichtweiten,
   SW_Koor
      INTEGER NOT NULL REFERENCES SW_Koor,
   folgt_auf_SW_Koor
      INTEGER REFERENCES SW_Koor
)

CREATE TABLE SW_Koor (
   SW_Koor_ID
      INTEGER NOT NULL PRIMARY KEY,
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 ),
   Sichtweite
      REAL NOT NULL, -- Meter
   CHECK ( Sichtweite>=0 )
)

CREATE TABLE Hoehendifferenz (
   Hoehendifferenz_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Hoehendifferenz_ID) REFERENCES allgemeine_Eigenschaften,
   hat_Spurbezeichnung
      INTEGER REFERENCES Spurbezeichnung
)

CREATE TABLE Hoehendifferenz__hat_HD_Punkt (
   Hoehendifferenz
      INTEGER NOT NULL REFERENCES Hoehendifferenz,
   HD_Punkt
      INTEGER NOT NULL REFERENCES HD_Punkt,
   folgt_auf_HD_Punkt
      INTEGER REFERENCES HD_Punkt
)

CREATE TABLE HD_Punkt (
   HD_Punkt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (HD_Punkt_ID) REFERENCES allgemeine_Eigenschaften,
   Station
      REAL NOT NULL, -- Meter
   CHECK ( Station>=0 ),
   Differenz
      REAL NOT NULL, -- Meter
   CHECK ( Differenz>=0 ),
   gehoert_zu_Hoehendifferenz
      INTEGER NOT NULL REFERENCES Hoehendifferenz
)

CREATE TABLE allgemeine_Eigenschaften (
   allgemeine_Eigenschaften_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bezeichnung
      VARCHAR(255),
   fachliche_Bedeutung
      VARCHAR(255) NOT NULL
)

CREATE TABLE allgemeine_Eigenschaften__Info (
   allgemeine_Eigenschaften
      INTEGER NOT NULL REFERENCES allgemeine_Eigenschaften,
   Informationstext
      VARCHAR(255) NOT NULL
)

