
CREATE SCHEMA Allgemeine_Geometrieobjekte

-- Historie:
--
-- 12.09.2001 - 1.001 (1.004)
-- berarbeitung in Folge des nderungsantrags A0006
-- ALKIS-Objekte in neues Schema Kataster verlegt
--
-- 29.10.2000 - 1.000 (1.001)
-- Schema in den OKSTRA integriert


CREATE TABLE Eigensch_allgem_Geometrieobj (
   Eigensch_allgem_Geometrieobj_ID
      INTEGER NOT NULL PRIMARY KEY,
   Bezeichnung
      VARCHAR(255)
)

CREATE TABLE Eigensch_allgem_Geometrieobj__Fachbedeutung (
   Eigensch_allgem_Geometrieobj
      INTEGER NOT NULL REFERENCES Eigensch_allgem_Geometrieobj,
   Fachbedeutung
      VARCHAR(255) NOT NULL
)

CREATE TABLE Eigensch_allgem_Geometrieobj__Informationstext (
   Eigensch_allgem_Geometrieobj
      INTEGER NOT NULL REFERENCES Eigensch_allgem_Geometrieobj,
   Informationstext
      VARCHAR(255) NOT NULL
)

CREATE TABLE allgemeines_Punktobjekt (
   allgemeines_Punktobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (allgemeines_Punktobjekt_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   FOREIGN KEY (allgemeines_Punktobjekt_ID) REFERENCES Entwurf.allgemeine_Eigenschaften
)

CREATE TABLE Symbol (
   Symbol_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Symbol_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   Symbolbedeutung
      VARCHAR(255) NOT NULL,
   Breite_links
      REAL NOT NULL, -- Groesse
   CHECK ( Breite_links>=0 ),
   Breite_rechts
      REAL NOT NULL, -- Groesse
   CHECK ( Breite_rechts>=0 ),
   Hoehe_oben
      REAL NOT NULL, -- Groesse
   CHECK ( Hoehe_oben>=0 ),
   Hoehe_unten
      REAL NOT NULL, -- Groesse
   CHECK ( Hoehe_unten>=0 ),
   Einheit
      INTEGER NOT NULL REFERENCES Einheit,
   Drehwinkel
      REAL NOT NULL, -- Winkel
   mit_Bezug_auf_allg_Punktobjekt
      INTEGER REFERENCES allgemeines_Punktobjekt
)

CREATE TABLE Einheit (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Einheit
      VARCHAR(4) NOT NULL
)

INSERT INTO Einheit VALUES (0,'Welt')
INSERT INTO Einheit VALUES (1,'mm')

CREATE TABLE allgemeines_Linienobjekt (
   allgemeines_Linienobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (allgemeines_Linienobjekt_ID) REFERENCES Geometrieschema.Linienobjekt_Modell,
   FOREIGN KEY (allgemeines_Linienobjekt_ID) REFERENCES Entwurf.allgemeine_Eigenschaften
)

CREATE TABLE Boeschungsschraffen (
   Boeschungsschraffen_ID
      INTEGER NOT NULL PRIMARY KEY,
   Boeschungsbedeutung
      VARCHAR(255) NOT NULL
)

CREATE TABLE Boeschungsschraffen__hat_Linie (
   Boeschungsschraffen
      INTEGER NOT NULL REFERENCES Boeschungsschraffen,
   allgemeines_Linienobjekt
      INTEGER NOT NULL REFERENCES allgemeines_Linienobjekt
)

CREATE TABLE allgemeines_Flaechenobjekt (
   allgemeines_Flaechenobjekt_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (allgemeines_Flaechenobjekt_ID) REFERENCES Geometrieschema.Flaechenobjekt_Modell,
   FOREIGN KEY (allgemeines_Flaechenobjekt_ID) REFERENCES Entwurf.allgemeine_Eigenschaften
)

CREATE TABLE Dreieck (
   Dreieck_ID
      INTEGER NOT NULL PRIMARY KEY,
   Dreiecksbedeutung
      VARCHAR(255) NOT NULL,
   in_DGM
      INTEGER NOT NULL REFERENCES Entwurf.DGM
)

CREATE TABLE Dreieck__hat_Punkte (
   Dreieck
      INTEGER NOT NULL REFERENCES Dreieck,
   allgemeines_Punktobjekt
      INTEGER NOT NULL REFERENCES allgemeines_Punktobjekt,
   folgt_auf_allgemeines_Punktobjekt
      INTEGER REFERENCES allgemeines_Punktobjekt
)

CREATE TABLE Dreieck__hat_Seiteneigensch (
   Dreieck
      INTEGER NOT NULL REFERENCES Dreieck,
   Seiteneigenschaft
      INTEGER NOT NULL REFERENCES Seiteneigenschaft,
   folgt_auf_Seiteneigenschaft
      INTEGER REFERENCES Seiteneigenschaft
)

CREATE TABLE Seiteneigenschaft (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Seiteneigenschaft
      VARCHAR(13) NOT NULL
)

INSERT INTO Seiteneigenschaft VALUES (1,'normale Seite')
INSERT INTO Seiteneigenschaft VALUES (2,'Bruchlinie')
INSERT INTO Seiteneigenschaft VALUES (3,'Formlinie')

CREATE TABLE Beschriftung (
   Beschriftung_ID
      INTEGER NOT NULL PRIMARY KEY,
   FOREIGN KEY (Beschriftung_ID) REFERENCES Geometrieschema.Punktobjekt_Modell,
   Text
      VARCHAR(255) NOT NULL, -- RTF
   Textbedeutung
      VARCHAR(255) NOT NULL,
   Breite
      REAL NOT NULL, -- Groesse
   CHECK ( Breite>=0 ),
   Hoehe
      REAL NOT NULL, -- Groesse
   CHECK ( Hoehe>=0 ),
   Einheit
      INTEGER REFERENCES Einheit,
   Drehwinkel
      REAL, -- Winkel
   Textneigung
      REAL, -- Winkel
   Schriftart
      VARCHAR(255),
   Kasten
      INTEGER REFERENCES Logical_Types.Boolean,
   Fahne
      INTEGER REFERENCES Fahne,
   vertikale_Ausrichtung
      INTEGER REFERENCES vertikale_Ausrichtung,
   horizontale_Ausrichtung
      INTEGER REFERENCES horizontale_Ausrichtung,
   zu_Punktobjekt_Modell
      INTEGER REFERENCES Geometrieschema.Punktobjekt_Modell
)

CREATE TABLE Fahne (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   Fahne
      VARCHAR(8) NOT NULL
)

INSERT INTO Fahne VALUES (0,'ohne')
INSERT INTO Fahne VALUES (1,'gerade')
INSERT INTO Fahne VALUES (2,'geknickt')

CREATE TABLE vertikale_Ausrichtung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   vertikale_Ausrichtung
      VARCHAR(9) NOT NULL
)

INSERT INTO vertikale_Ausrichtung VALUES (0,'zentriert')
INSERT INTO vertikale_Ausrichtung VALUES (1,'oberhalb')
INSERT INTO vertikale_Ausrichtung VALUES (2,'unterhalb')

CREATE TABLE horizontale_Ausrichtung (
   Kennung
      INTEGER NOT NULL PRIMARY KEY,
   horizontale_Ausrichtung
      VARCHAR(9) NOT NULL
)

INSERT INTO horizontale_Ausrichtung VALUES (0,'zentriert')
INSERT INTO horizontale_Ausrichtung VALUES (1,'links')
INSERT INTO horizontale_Ausrichtung VALUES (2,'rechts')

